@@ -3,46 +3,62 @@ from textwrap import dedent
 from dataclasses import dataclass
 from os.path import basename
 from typing import *
+from enum import Enum
+
 from . import log
 
 @dataclass
-class SusLocation():
+class Location():
     file: Any
     line: int
     col: int
     dur: int
     def __repr__(self):
         return f"{basename(self.file.path)}:{self.line}:{self.col}({self.dur})"
+    def __hash__(self) -> int:
+        return hash(self.file.source) + self.line + self.col + self.dur
+
+class DiagLevel(Enum):
+    ERROR = 1
+    WARN = 2
+    INFO = 3
+
+@dataclass
+class Diagnostic():
+    locations: list[Location]
+    level: DiagLevel
+    message: str
 
 class SusError(Exception):
     pass
 
 SINGLE_LINE_ERRORS = False
-class SusSourceError(SusError):
-    def __init__(self, locations: list[SusLocation], text):
-        self.locations = locations
-        self.text = text
-        self.accent = Fore.RED
+class SourceError(SusError):
+    def __init__(self, diag: Diagnostic):
+        self.diag = diag
+        self.accent = {
+            DiagLevel.ERROR: Fore.RED,
+            DiagLevel.WARN: Fore.YELLOW,
+            DiagLevel.INFO: Fore.BLUE,
+        }[diag.level]
 
-    def print_err(self):
-        self.accent = Fore.RED
-        log.error(str(self))
-    def print_warn(self):
-        self.accent = Fore.YELLOW
-        log.warn(str(self))
-    def print_info(self):
-        self.accent = Fore.BLUE
-        log.info(str(self))
+    def print(self):
+        function = {
+            DiagLevel.ERROR: log.error,
+            DiagLevel.WARN: log.warn,
+            DiagLevel.INFO: log.info,
+        }[self.diag.level]
+        function(str(self))
 
     def __str__(self):
         if SINGLE_LINE_ERRORS:
-            location = self.locations[0]
+            location = self.diag.locations[0]
             location = f"{location.file.path}:{location.line}:{location.col}"
             return f"{location}: {self.text}"
 
-        error = Fore.WHITE + ("" if len(self.locations) in [0, 1] else "multiple locations: ")
+        error = Fore.WHITE + ("" if len(self.diag.locations) in [0, 1] else "multiple locations: ")
 
-        for loc in self.locations:
+        for loc in self.diag.locations:
             padding = " " * (len(str(loc.line)) + 4 + loc.col - 1)
             squiggly = "~" * loc.dur if loc.dur > 0 else "^"
             src_line = loc.file.source.split('\n')[loc.line - 1]
@@ -60,10 +76,17 @@ class SusSourceError(SusError):
             {padding}{self.accent}{squiggly}
             """)
 
-        error += f"{self.accent}{self.text}{Fore.RESET}\n"
+        error += f"{self.accent}{self.diag.message}{Fore.RESET}\n"
         return error.strip("\n")
 
-class SusOutputError(SusError):
+class OutputError(SusError):
+    def __init__(self, msg):
+        self.msg = msg
+
+    def __str__(self):
+        return self.msg
+
+class SearchError(SusError):
     def __init__(self, msg):
         self.msg = msg
 
